@@ -12,7 +12,7 @@ setMethod("rangeMapExport",
 					'select name from sqlite_master where type = "table" and 
 						(tbl_name like "MAP_%")')$name
 		
-		if(length(mapnams) == 0) stop(x.Msg("The project does not contain any MAP tables!"))
+		if(length(mapnams) == 0) stop("The project does not contain any MAP tables!")
 		
 		wd = setwd(dirName)
 		
@@ -33,7 +33,7 @@ setMethod("rangeMapExport",
 rangeMap.export  <- function(con, dirName = dirName, ...) {
 	
 	x = new("rangeMap", CON = con)
-	if(missing(dirName))  dirName =  dirname(dbGetInfo(CON)$dbname)
+	if(missing(dirName))  dirName =  dirname(dbGetInfo(con)$dbname)
 	
 	rangeMapExport(x, dirName = dirName, ...)	
 
